from urllib.parse import urljoin
from bs4 import BeautifulSoup

from .core import Check
from .registry import register
from ..fetch import requests_session
from ..issues import Issues, Issue


MAX_IMG_SIZE = 1_000_000  # 1 MB


@register
class LargeImgCheck(Check):
    def run(self):
        issues = Issues()
        soup = BeautifulSoup(self.content, "html.parser")
        for img in soup.findAll("img"):
            src = img.get("src")
            full_src = urljoin(self.url, src)
            response = requests_session.head(
                full_src, allow_redirects=True  # not enabled on head by default
            )
            if response.ok:
                size = response.headers.get("Content-Length", None)
                if size is not None and int(size) > MAX_IMG_SIZE:
                    issues.append(
                        Issue.from_type(
                            type="img-filesize-too-large",
                            url=self.url,
                            extra={"element": str(full_src)},
                        )
                    )
        return issues
